Learn R Programming

baseballr (version 1.2.0)

baseballr-package: baseballr: Acquiring and Analyzing Baseball Data

Description

logo

Provides numerous utilities for acquiring and analyzing baseball data from online sources such as Baseball Reference <https://www.baseball-reference.com/>, FanGraphs <https://www.fangraphs.com/>, and the MLB Stats API <https://www.mlb.com/>.

Arguments

Author

Maintainer: Saiem Gilani saiem.gilani@gmail.com

Authors:

Other contributors:

See Also