chadwick_player_id_lu: *Look up Baseball Player IDs by Player Name*

playerid_lookupR Documentation

Look up Baseball Player IDs by Player Name

Description

This function allows you to query the Chadwick Bureau's public register of baseball players and the various IDs associated with them in different systems of record.

Usage

playerid_lookup(last_name = NULL, first_name = NULL)

Arguments

last_name

A text string used to return results for players with that string in their last name.

first_name

A text string used to return results for players with that string in their first name.

Value

A data frame of baseball players and the various IDs associated with them in different systems of record.

col_name types description
first_name character Player first name.
last_name character Player last name.
given_name character Player full given (legal) name.
name_suffix character Name suffix (e.g. Jr., Sr., III).
nick_name character Player nickname.
birth_year integer Year of birth.
mlb_played_first integer First MLB season as a player.
mlbam_id integer MLB Advanced Media (MLBAM) player ID.
retrosheet_id character Retrosheet player ID.
bbref_id character Baseball-Reference player ID.
fangraphs_id integer FanGraphs player ID.

Examples


  try(playerid_lookup("Garcia", "Karim"))


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.