chadwick_player_name_lu: *Look up Baseball Player Name by ID*

playername_lookupR Documentation

Look up Baseball Player Name by ID

Description

This function allows you to query the Chadwick Bureau's public register of baseball players and the various IDs associated with them in different systems of record.

Usage

playername_lookup(id)

Arguments

id

An integer or character string representing a player ID in a baseball database, cross-referenced through the Chadwick Bureau's public register of baseball players.

Value

A data frame of baseball players and the various IDs associated with them in different systems of record.

col_name types description
name_first character Player first name.
name_last character Player last name.
name_given character Player full given (legal) name.
name_suffix character Name suffix (e.g. Jr., Sr., III).
name_nick character Player nickname.
birth_year integer Year of birth.
mlb_played_first integer First MLB season as a player.
key_mlbam integer MLB Advanced Media (MLBAM) player ID.
key_retro character Retrosheet player ID.
key_bbref character Baseball-Reference player ID.
key_fangraphs integer FanGraphs player ID.

Examples


  try(playername_lookup(4885))
  try(playername_lookup("kaaihki01"))


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.