mlb_awards_recipient: *MLB Award Recipients*

View source: R/mlb_awards_recipient.R

mlb_awards_recipientR Documentation

MLB Award Recipients

Description

MLB Award Recipients

Usage

mlb_awards_recipient(
  award_id = NULL,
  sport_id = NULL,
  league_id = NULL,
  season = NULL
)

Arguments

award_id

award_id to return a directory of players for a given award.

sport_id

sport_id to return a directory of players for a given aware in a specific sport.

league_id

league_id(s) to return a directory of players for a given award in a specific league. Format '103,104'

season

Year(s) to return a directory of players for a given award in a given season.

Value

Returns a tibble with the following columns

col_name types description
award_id character Award identifier code.
award_name character Award name.
date character Date the award was given (YYYY-MM-DD).
season character Season the award was given (YYYY).
votes integer Number of votes received.
notes character Additional notes about the recipient.
player_id integer MLB player ID of the recipient.
player_link character MLB Stats API relative player link.
player_name_first_last character Recipient name in first-last order.
player_primary_position_code character Recipient primary fielding position code.
player_primary_position_name character Recipient primary fielding position name.
player_primary_position_type character Recipient primary position type.
player_primary_position_abbreviation character Recipient primary position abbreviation.
team_id integer MLB team ID of the recipient.
team_link character MLB Stats API relative team link.

Examples


  try(mlb_awards_recipient(award_id = 'MLBHOF', season = 2020))


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.