mlb_fielder_detail_types: *MLB Fielder Detail Types*

View source: R/mlb_fielder_detail_types.R

mlb_fielder_detail_typesR Documentation

MLB Fielder Detail Types

Description

MLB Fielder Detail Types

Usage

mlb_fielder_detail_types()

Value

Returns a tibble with the following columns

col_name types description
stat_name character Internal fielder detail stat name.
code character Fielder detail type code.
names list Associated detail names for the type.
chance logical Whether the detail counts as a fielding chance.
error logical Whether the detail counts as an error.

Examples


  try(mlb_fielder_detail_types())


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.