mlb_game_endpoints: *MLB Game Endpoint Overview*

mlb_game_endpointsR Documentation

MLB Game Endpoint Overview

Description

  • mlb_game_info(): Retrieve additional game information for major and minor league games.

  • mlb_game_pks(): Get MLB Game Info by Date and Level.

  • mlb_game_content(): Retrieve additional game content for major and minor league games.

  • mlb_game_linescore(): Retrieve game linescores for major and minor league games.

  • mlb_game_wp(): Acquire win probability for Major and Minor League games.

  • mlb_game_pace(): Retrieve game pace metrics for major and minor league.

  • mlb_game_changes(): Acquire time codes for Major and Minor League games.

  • mlb_game_context_metrics(): Acquire game context metrics for Major and Minor League games.

  • mlb_pbp(): Acquire pitch-by-pitch data for Major and Minor League games.

  • mlb_pbp_diff(): Acquire pitch-by-pitch data between two timecodes for Major and Minor League games.

Details

MLB Game

These functions retrieve MLB game information, content, linescores, win probability, pace, changes, context metrics, and pitch-by-pitch data from the MLB Stats API.


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.