mlb_game_info: *Retrieve additional game information for major and minor...

View source: R/mlb_game_info.R

mlb_game_infoR Documentation

Retrieve additional game information for major and minor league games

Description

Retrieve additional game information for major and minor league games

Usage

mlb_game_info(game_pk)

Arguments

game_pk

The unique game_pk identifier for the game

Value

Returns a tibble that includes supplemental information, such as weather, official scorer, attendance, etc., for the game_pk provided

col_name types description
game_date character Game date (YYYY-MM-DD).
game_pk numeric Unique game identifier.
venue_name character Stadium name.
venue_id integer Venue ID.
temperature character Game-time temperature (degrees F).
other_weather character Weather condition description.
wind character Wind speed and direction.
attendance character Reported game attendance.
start_time character First-pitch local start time.
elapsed_time character Total elapsed game time (H:MM).
game_id character Human-readable game ID slug.
game_type character Game type code (R, P, etc.).
home_sport_code character Home sport code (always 'mlb').
official_scorer character Official scorer name.
date character Long-form game date label.
status_ind character Game status code.
home_league_id integer Home team league ID.
gameday_sw character Gameday data type code.

Examples


  try(mlb_game_info(game_pk = 566001))


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.