View source: R/mlb_high_low_stats.R
| mlb_high_low_stats | R Documentation |
Acquire high/low stats for Major and Minor Leagues
mlb_high_low_stats(
org_type,
season,
sort_stat,
team_ids = NULL,
league_ids = NULL,
sport_ids = NULL,
game_type = NULL,
stat_group = NULL,
limit = NULL
)
org_type |
The organization type for return information (Required). Valid values include:
| |||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
season |
The season for which you want to return information (Required). | |||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
sort_stat |
The stat to sort the return (Required). Valid values can be found from 'stat_lookup_param' below
| |||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
team_ids |
The team_id(s) for which to return information. | |||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
league_ids |
The league_id(s) for which to return information. | |||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
sport_ids |
The sport_id(s) for which to return information. | |||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
game_type |
The game_type for which to return information. | |||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
stat_group |
Stat group for which to return information. Valid values include:
| |||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
limit |
Number of records as the limit of the return. |
Returns a tibble with the following columns
| col_name | types | description |
| total_splits | integer | Total number of split records matching the query. |
| season | integer | Season year for the split. |
| date | character | Date of the game (YYYY-MM-DD). |
| is_home | logical | Whether the subject team was the home team. |
| rank | integer | Rank of the split within the high/low leaderboard. |
| game_innings | integer | Number of innings played in the game. |
| stat_at_bats | integer | Value of the sorted statistic (here at bats) for the split. |
| team_id | integer | MLB team id for the subject team. |
| team_name | character | Subject team name. |
| team_link | character | API relative link to the subject team. |
| opponent_id | integer | MLB team id for the opponent. |
| opponent_name | character | Opponent team name. |
| opponent_link | character | API relative link to the opponent team. |
| game_pk | integer | MLB game primary key. |
| game_link | character | API relative link to the game live feed. |
| game_number | integer | Game number within a day (1 unless a doubleheader). |
| game_day_night | character | Day/night designation of the game ('day' or 'night'). |
| game_content_link | character | API relative link to the game content endpoint. |
| home_team_id | integer | Home team id (populated for game-level org types). |
| home_team_name | character | Home team name (populated for game-level org types). |
| home_team_link | character | API relative link to the home team. |
| away_team_id | integer | Away team id (populated for game-level org types). |
| away_team_name | character | Away team name (populated for game-level org types). |
| away_team_link | character | API relative link to the away team. |
| combined_stats | logical | Whether the stat combines multiple split sources. |
| group_display_name | character | Stat group display name (e.g. 'hitting'). |
| game_type_id | character | Single-letter game type code (e.g. 'R'). |
| game_type_description | character | Game type description (e.g. 'Regular Season'). |
| sort_stat_name | character | Snake-case name of the sorted statistic (e.g. 'at_bats'). |
| sort_stat_lookup_param | character | API lookup parameter for the sorted statistic (e.g. 'atBats'). |
| sort_stat_is_counting | logical | Whether the sorted statistic is a counting stat. |
| sort_stat_label | character | Human-readable label of the sorted statistic (e.g. 'At bats'). |
try(mlb_high_low_stats(org_type = 'Team', season = 2020, sort_stat = 'atBats'))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.