mlb_high_low_types: *MLB Stat High/Low Types*

View source: R/mlb_high_low_types.R

mlb_high_low_typesR Documentation

MLB Stat High/Low Types

Description

MLB Stat High/Low Types

Usage

mlb_high_low_types()

Value

Returns a tibble with the following columns

col_name types description
stat_name character Snake-case name of the statistic (e.g. 'at_bats').
stat_lookup_param character API lookup parameter for the statistic (e.g. 'atBats').
is_counting logical Whether the statistic is a counting stat.
stat_label character Human-readable label of the statistic (e.g. 'At bats').
stat_groups list List-column of stat group display names the stat belongs to.
org_types list List-column of organization types the stat applies to (e.g. PLAYER).
high_low_types list List-column of high/low aggregation types (e.g. PLAYER, TEAM, GAME).

Examples


  try(mlb_high_low_types())


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.