mlb_metrics: *MLB Metrics*

View source: R/mlb_metrics.R

mlb_metricsR Documentation

MLB Metrics

Description

MLB Metrics

Usage

mlb_metrics()

Value

Returns a tibble with the following columns

col_name types description
metric_name character Metric name (e.g. 'releaseSpinRate').
metric_id integer Numeric metric identifier.
stat_group character Stat group the metric belongs to (e.g. 'pitching').
metric_unit character Unit of measure for the metric (e.g. 'RPM').

Examples


  try(mlb_metrics())


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.