mlb_people_free_agents: *Find Information About MLB Free Agents*

View source: R/mlb_people_free_agents.R

mlb_people_free_agentsR Documentation

Find Information About MLB Free Agents

Description

Find Information About MLB Free Agents

Usage

mlb_people_free_agents(season = NULL)

Arguments

season

Season preceding free agency

Value

Returns a tibble with the following columns:

col_name types description
date_declared character Date the player declared free agency (YYYY-MM-DD).
notes character Notes on the signing (e.g. 'One-year contract').
date_signed character Date the player signed a new contract (YYYY-MM-DD).
sort_order integer Display sort order for the free agent record.
player_id integer MLB player id of the free agent.
player_full_name character Free agent full name.
player_link character API relative link to the player.
original_team_id integer Team id the player left.
original_team_name character Name of the team the player left.
original_team_link character API relative link to the original team.
position_code character Player position code.
position_name character Player position name (e.g. 'Relief Pitcher').
position_type character Player position type (e.g. 'Pitcher').
position_abbreviation character Player position abbreviation (e.g. 'RP').
new_team_id integer Team id the player signed with.
new_team_name character Name of the team the player signed with.
new_team_link character API relative link to the new team.

Examples


  try(mlb_people_free_agents(season = 2018))


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.