mlb_pitch_codes: *MLB Pitch Codes*

View source: R/mlb_pitch_codes.R

mlb_pitch_codesR Documentation

MLB Pitch Codes

Description

MLB Pitch Codes

Usage

mlb_pitch_codes()

Value

Returns a tibble with the following columns

col_name types description
pitch_code character Single-character code identifying the pitch result.
pitch_description character Human-readable description of the pitch code.
swing_status logical Whether the code represents a swing.
swing_miss_status logical Whether the code represents a swinging strike (miss).
swing_contact_status logical Whether the code represents a swing that made contact.
sort_order integer Display sort order for the pitch code.
strike_status logical Whether the code counts as a strike.
ball_status logical Whether the code counts as a ball.
pitch_status logical Whether the code represents a pitch (vs. non-pitch event).
pitch_result_text character Display text for the pitch result.
bunt_attempt_status logical Whether the code represents a bunt attempt.
contact_status logical Whether the code represents bat-ball contact.

Examples


  try(mlb_pitch_codes())


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.