mlb_pitch_types: *MLB Pitch Types*

View source: R/mlb_pitch_types.R

mlb_pitch_typesR Documentation

MLB Pitch Types

Description

MLB Pitch Types

Usage

mlb_pitch_types()

Value

Returns a tibble with the following columns

col_name types description
pitch_type_code character Short code identifying the pitch type (e.g. 'FA').
pitch_type_description character Full name of the pitch type (e.g. 'Fastball').

Examples


  try(mlb_pitch_types())


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.