mlb_probables: *Retrieve probable starters for a given MLB game*

View source: R/mlb_probables.R

mlb_probablesR Documentation

Retrieve probable starters for a given MLB game

Description

Retrieve probable starters for a given MLB game

Usage

mlb_probables(game_pk)

Arguments

game_pk

The unique game_pk identifier for the game

Value

Returns a tiible that includes probable starting pitchers and the home plate umpire for the game_pk requested including the following columns:

col_name types description
game_pk integer Unique game identifier.
game_date character Date of the game (YYYY-MM-DD).
fullName character Full name of the probable starting pitcher.
id integer MLBAM player ID of the probable starting pitcher.
team character Team name for the probable pitcher.
team_id integer MLBAM team ID for the probable pitcher.
home_plate_full_name character Full name of the home plate umpire.
home_plate_id integer MLBAM ID of the home plate umpire.

Examples


  try(mlb_probables(566001))


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.