mlb_situation_codes: *MLB Situation Codes*

View source: R/mlb_situation_codes.R

mlb_situation_codesR Documentation

MLB Situation Codes

Description

MLB Situation Codes

Usage

mlb_situation_codes()

Value

Returns a tibble with the following columns

col_name types description
situation_code character Code identifying the game situation.
sort_order integer Display sort order for the situation code.
navigation_menu character Navigation menu grouping (e.g. 'Game').
situation_code_description character Description of the situation (e.g. 'Home Games').
team logical Whether the situation applies to team stats.
batting logical Whether the situation applies to batting stats.
fielding logical Whether the situation applies to fielding stats.
pitching logical Whether the situation applies to pitching stats.

Examples


  try(mlb_situation_codes())


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.