mlb_teams: *MLB Teams*

View source: R/mlb_teams.R

mlb_teamsR Documentation

MLB Teams

Description

MLB Teams

Usage

mlb_teams(
  season = NULL,
  active_status = NULL,
  all_star_statuses = NULL,
  league_ids = NULL,
  sport_ids = NULL,
  game_type = NULL
)

Arguments

season

Year to return to return team information for.

active_status

The active statuses to populate teams for a given season.

all_star_statuses

The all-star statuses to populate teams for a given season.

league_ids

The league_id(s) to return team information for.

sport_ids

The sport_id(s) to return team information for.

game_type

The game_type to return team information for.

Value

Returns a tibble with the following columns

col_name types description
all_star_status character All-star status flag.
team_id integer Team MLBAM ID.
team_full_name character Full team name.
link character API link to the team.
season integer Season year.
team_code character Internal team code.
file_code character File code abbreviation.
team_abbreviation character Team abbreviation.
team_name character Short team name.
location_name character Team location (city).
first_year_of_play character First year the franchise played.
short_name character Short display name.
franchise_name character Franchise name.
club_name character Club name.
active logical Whether the team is active.
spring_league_id integer Spring league MLBAM ID.
spring_league_name character Spring league name.
spring_league_link character API link to the spring league.
spring_league_abbreviation character Spring league abbreviation.
venue_id integer Home venue MLBAM ID.
venue_name character Home venue name.
venue_link character API link to the venue.
spring_venue_id integer Spring training venue MLBAM ID.
spring_venue_link character API link to the spring venue.
league_id integer League MLBAM ID.
league_name character League name.
league_link character API link to the league.
division_id integer Division MLBAM ID.
division_name character Division name.
division_link character API link to the division.
sport_id integer Sport MLBAM ID.
sport_link character API link to the sport.
sport_name character Sport name (e.g., Major League Baseball).

Examples


  try(mlb_teams(season = 2021, sport_ids = c(1)))


baseballr documentation built on Aug. 27, 2026, 1:07 a.m.