Create stat lines from Statcast data
Source:R/sch_statline_from_statcast.R
statline_from_statcast.RdThis function allows you to create stat lines of statistics for players or groups of players from raw Statcast. When calculating wOBA, the most recent year in the data frame is used for weighting.
Details
statline_from_statcast(df, base = "contact")