Skip to contents

This function allows you to query the Chadwick Bureau's public register of baseball players and the various IDs associated with them in different systems of record.

Usage

playerid_lookup(last_name = NULL, first_name = NULL)

Arguments

last_name

A text string used to return results for players with that string in their last name.

first_name

A text string used to return results for players with that string in their first name.

Value

A data frame of baseball players and the various IDs associated with them in different systems of record.

col_nametypesdescription
first_namecharacterPlayer first name.
last_namecharacterPlayer last name.
given_namecharacterPlayer full given (legal) name.
name_suffixcharacterName suffix (e.g. Jr., Sr., III).
nick_namecharacterPlayer nickname.
birth_yearintegerYear of birth.
mlb_played_firstintegerFirst MLB season as a player.
mlbam_idintegerMLB Advanced Media (MLBAM) player ID.
retrosheet_idcharacterRetrosheet player ID.
bbref_idcharacterBaseball-Reference player ID.
fangraphs_idintegerFanGraphs player ID.

Examples

# \donttest{
  try(playerid_lookup("Garcia", "Karim"))
#> ── Player ID Lookup from the Chadwick Bureau's public register of baseba
#>  Data updated: 2026-06-12 14:07:21 UTC
#> # A tibble: 0 × 11
#> # ℹ 11 variables: first_name <chr>, last_name <chr>, given_name <chr>,
#> #   name_suffix <chr>, nick_name <chr>, birth_year <int>,
#> #   mlb_played_first <int>, mlbam_id <int>, retrosheet_id <chr>,
#> #   bbref_id <chr>, fangraphs_id <int>
# }