| playerid_lookup | R Documentation |
This function allows you to query the Chadwick Bureau's public register of baseball players and the various IDs associated with them in different systems of record.
playerid_lookup(last_name = NULL, first_name = NULL)
last_name |
A text string used to return results for players with that string in their last name. |
first_name |
A text string used to return results for players with that string in their first name. |
A data frame of baseball players and the various IDs associated with them in different systems of record.
| col_name | types | description |
| first_name | character | Player first name. |
| last_name | character | Player last name. |
| given_name | character | Player full given (legal) name. |
| name_suffix | character | Name suffix (e.g. Jr., Sr., III). |
| nick_name | character | Player nickname. |
| birth_year | integer | Year of birth. |
| mlb_played_first | integer | First MLB season as a player. |
| mlbam_id | integer | MLB Advanced Media (MLBAM) player ID. |
| retrosheet_id | character | Retrosheet player ID. |
| bbref_id | character | Baseball-Reference player ID. |
| fangraphs_id | integer | FanGraphs player ID. |
try(playerid_lookup("Garcia", "Karim"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.