Learn R Programming

baseballr (version 2.0.0)

chadwick_player_lu: Download the Chadwick Bureau's public register of baseball players

Description

Download the Chadwick Bureau's public register of baseball players

Usage

chadwick_player_lu()

get_chadwick_lu()

Arguments

Value

A data frame of baseball players and the various IDs associated with them in different systems of record and the following columns:

col_nametypesdescription
key_personcharacterChadwick Bureau primary person key.
key_uuidcharacterChadwick Bureau universally unique identifier for the person.
key_mlbamintegerMLB Advanced Media (MLBAM) player ID.
key_retrocharacterRetrosheet player ID.
key_bbrefcharacterBaseball-Reference major league player ID.
key_bbref_minorscharacterBaseball-Reference minor league player ID.
key_fangraphsintegerFanGraphs player ID.
key_npbintegerNippon Professional Baseball (Japan) player ID.
key_sr_nflcharacterSports Reference NFL player ID.
key_sr_nbacharacterSports Reference NBA player ID.
key_sr_nhlcharacterSports Reference NHL player ID.
key_wikidatacharacterWikidata entity ID for the person.
name_lastcharacterPlayer last name.
name_firstcharacterPlayer first name.
name_givencharacterPlayer full given (legal) name.
name_suffixcharacterName suffix (e.g. Jr., Sr., III).
name_matrilinealcharacterMaternal surname, where recorded.
name_nickcharacterPlayer nickname.
birth_yearintegerYear of birth.
birth_monthintegerMonth of birth.
birth_dayintegerDay of birth.
death_yearintegerYear of death.
death_monthintegerMonth of death.
death_dayintegerDay of death.
pro_played_firstintegerFirst season the person played professional baseball.
pro_played_lastintegerLast season the person played professional baseball.
mlb_played_firstintegerFirst MLB season as a player.
mlb_played_lastintegerLast MLB season as a player.
col_played_firstintegerFirst college season as a player.
col_played_lastintegerLast college season as a player.
pro_managed_firstintegerFirst professional season as a manager.
pro_managed_lastintegerLast professional season as a manager.
mlb_managed_firstintegerFirst MLB season as a manager.
mlb_managed_lastintegerLast MLB season as a manager.
col_managed_firstintegerFirst college season as a manager.
col_managed_lastintegerLast college season as a manager.
pro_umpired_firstintegerFirst professional season as an umpire.
pro_umpired_lastintegerLast professional season as an umpire.
mlb_umpired_firstintegerFirst MLB season as an umpire.
mlb_umpired_lastintegerLast MLB season as an umpire.

A data frame of baseball players and the various IDs associated with them in different systems of record.

Examples

Run this code
# \donttest{
  try(chadwick_player_lu())
# }

Run the code above in your browser using DataLab