Skip to contents

This function allows you to query the Chadwick Bureau's public register of baseball players and the various IDs associated with them in different systems of record.

Usage

playername_lookup(id)

Arguments

id

An integer or character string representing a player ID in a baseball database, cross-referenced through the Chadwick Bureau's public register of baseball players.

Value

A data frame of baseball players and the various IDs associated with them in different systems of record.

col_nametypesdescription
name_firstcharacterPlayer first name.
name_lastcharacterPlayer last name.
name_givencharacterPlayer full given (legal) name.
name_suffixcharacterName suffix (e.g. Jr., Sr., III).
name_nickcharacterPlayer nickname.
birth_yearintegerYear of birth.
mlb_played_firstintegerFirst MLB season as a player.
key_mlbamintegerMLB Advanced Media (MLBAM) player ID.
key_retrocharacterRetrosheet player ID.
key_bbrefcharacterBaseball-Reference player ID.
key_fangraphsintegerFanGraphs player ID.

Examples

# \donttest{
  try(playername_lookup(4885))
#> ── Player Name Lookup from the Chadwick Bureau's public register of base
#>  Data updated: 2026-06-09 20:41:44 UTC
#> # A tibble: 1 × 11
#>   name_first name_last name_given  name_suffix name_nick  birth_year
#>   <chr>      <chr>     <chr>       <chr>       <chr>           <int>
#> 1 Nyjer      Morgan    Nyjer Jamid ""          Tony Plush       1980
#> # ℹ 5 more variables: mlb_played_first <int>, key_mlbam <int>,
#> #   key_retro <chr>, key_bbref <chr>, key_fangraphs <int>
  try(playername_lookup("kaaihki01"))
#> ── Player Name Lookup from the Chadwick Bureau's public register of base
#>  Data updated: 2026-06-09 20:41:48 UTC
#> # A tibble: 1 × 11
#>   name_first name_last name_given name_suffix name_nick birth_year
#>   <chr>      <chr>     <chr>      <chr>       <chr>          <int>
#> 1 Kila       Ka'aihue  Micah Kila ""          ""              1984
#> # ℹ 5 more variables: mlb_played_first <int>, key_mlbam <int>,
#> #   key_retro <chr>, key_bbref <chr>, key_fangraphs <int>
# }