| playername_lookup | R Documentation |
This function allows you to query the Chadwick Bureau's public register of baseball players and the various IDs associated with them in different systems of record.
playername_lookup(id)
id |
An integer or character string representing a player ID in a baseball database, cross-referenced through the Chadwick Bureau's public register of baseball players. |
A data frame of baseball players and the various IDs associated with them in different systems of record.
| col_name | types | description |
| name_first | character | Player first name. |
| name_last | character | Player last name. |
| name_given | character | Player full given (legal) name. |
| name_suffix | character | Name suffix (e.g. Jr., Sr., III). |
| name_nick | character | Player nickname. |
| birth_year | integer | Year of birth. |
| mlb_played_first | integer | First MLB season as a player. |
| key_mlbam | integer | MLB Advanced Media (MLBAM) player ID. |
| key_retro | character | Retrosheet player ID. |
| key_bbref | character | Baseball-Reference player ID. |
| key_fangraphs | integer | FanGraphs player ID. |
try(playername_lookup(4885))
try(playername_lookup("kaaihki01"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.