Skip to contents

Retrieve additional game content for major and minor league games

Usage

mlb_game_content(game_pk)

Arguments

game_pk

The unique game_pk identifier for the game

Value

Returns a tibble of game content data with the following columns:

col_nametypesdescription
titlecharacterMedia/EPG title (e.g. MLBTV).
call_letterscharacterBroadcaster call letters.
espn_auth_requiredlogicalWhether ESPN authentication is required.
tbs_auth_requiredlogicalWhether TBS authentication is required.
espn2auth_requiredlogicalWhether ESPN2 authentication is required.
game_datecharacterGame date associated with the content.
content_idcharacterContent identifier.
fs1auth_requiredlogicalWhether FS1 authentication is required.
media_idcharacterMedia identifier.
media_feed_typecharacterMedia feed type (HOME/AWAY/NATIONAL).
mlbn_auth_requiredlogicalWhether MLB Network authentication is required.
fox_auth_requiredlogicalWhether FOX authentication is required.
media_feed_sub_typecharacterMedia feed sub-type code.
free_gamelogicalWhether the broadcast is a free game.
epg_idintegerElectronic programming guide identifier.
media_statecharacterMedia state (e.g. MEDIA_ARCHIVE).
abc_auth_requiredlogicalWhether ABC authentication is required.
rendition_namecharacterMedia rendition name.
descriptioncharacterContent description.
languagecharacterBroadcast language.
typecharacterContent/media type.

Examples

# \donttest{
  try(mlb_game_content(game_pk = 566001))
#> ── MLB Game Content data from MLB.com ─────────────── baseballr 2.0.0 ──
#>  Data updated: 2026-06-12 14:09:29 UTC
#> # A tibble: 8 × 21
#>   title       call_letters espn_auth_required tbs_auth_required
#>   <chr>       <chr>        <lgl>              <lgl>            
#> 1 MLBTV       SNY          FALSE              FALSE            
#> 2 MLBTV       FSO          FALSE              FALSE            
#> 3 MLBTV-Audio NA           NA                 NA               
#> 4 MLBTV-Audio NA           NA                 NA               
#> 5 MLBTV-Audio NA           NA                 NA               
#> 6 Audio       WCBS 880     NA                 NA               
#> 7 Audio       WLW          NA                 NA               
#> 8 Audio       ESPN-1050    NA                 NA               
#> # ℹ 17 more variables: espn2auth_required <lgl>, game_date <chr>,
#> #   content_id <chr>, fs1auth_required <lgl>, media_id <chr>,
#> #   media_feed_type <chr>, mlbn_auth_required <lgl>,
#> #   fox_auth_required <lgl>, media_feed_sub_type <chr>,
#> #   free_game <lgl>, epg_id <int>, media_state <chr>,
#> #   abc_auth_required <lgl>, rendition_name <chr>, description <chr>,
#> #   language <chr>, type <chr>
# }