View source: R/mlb_game_content.R
| mlb_game_content | R Documentation |
Retrieve additional game content for major and minor league games
mlb_game_content(game_pk)
game_pk |
The unique game_pk identifier for the game |
Returns a tibble of game content data with the following columns:
| col_name | types | description |
| title | character | Media/EPG title (e.g. MLBTV). |
| call_letters | character | Broadcaster call letters. |
| espn_auth_required | logical | Whether ESPN authentication is required. |
| tbs_auth_required | logical | Whether TBS authentication is required. |
| espn2auth_required | logical | Whether ESPN2 authentication is required. |
| game_date | character | Game date associated with the content. |
| content_id | character | Content identifier. |
| fs1auth_required | logical | Whether FS1 authentication is required. |
| media_id | character | Media identifier. |
| media_feed_type | character | Media feed type (HOME/AWAY/NATIONAL). |
| mlbn_auth_required | logical | Whether MLB Network authentication is required. |
| fox_auth_required | logical | Whether FOX authentication is required. |
| media_feed_sub_type | character | Media feed sub-type code. |
| free_game | logical | Whether the broadcast is a free game. |
| epg_id | integer | Electronic programming guide identifier. |
| media_state | character | Media state (e.g. MEDIA_ARCHIVE). |
| abc_auth_required | logical | Whether ABC authentication is required. |
| rendition_name | character | Media rendition name. |
| description | character | Content description. |
| language | character | Broadcast language. |
| type | character | Content/media type. |
try(mlb_game_content(game_pk = 566001))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.