View source: R/mlb_game_timecodes.R
| mlb_game_timecodes | R Documentation |
Acquire time codes for Major and Minor League games
mlb_game_timecodes(game_pk)
game_pk |
The game_pk for the game requested |
Returns a tibble that includes time codes from the game_pk requested
| col_name | types | description |
| timecodes | character | Play snapshot time code in 'YYYYMMDD_HHMMSS' format. |
try(mlb_game_timecodes(game_pk = 632970))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.