Skip to contents

Find game_pk values for professional baseball postseason games (major and minor leagues)

Usage

mlb_schedule_postseason(
  season = 2021,
  game_type = NULL,
  series_number = NULL,
  sport_id = 1,
  team_id = NULL
)

Arguments

season

The season for which you want to find game_pk values for MLB games

game_type

game_type to return schedule information for all tied games in a particular game_type

series_number

The Series number to return schedule information for all tied games in a particular series number

sport_id

The sport_id to return schedule information for.

team_id

The team_id to return schedule information for.

game_type_idgame_type_description
SSpring Training
RRegular Season
FWild Card Game
DDivision Series
LLeague Championship Series
WWorld Series
CChampionship
NNineteenth Century Series
PPlayoffs
AAll-Star Game
IIntrasquad
EExhibition

Value

Returns a tibble that includes game_pk values and additional information for games scheduled or played

col_nametypesdescription
datecharacterCalendar date for the schedule entry.
total_itemsintegerTotal schedule items on the date.
total_eventsintegerTotal non-game events on the date.
total_gamesintegerTotal games on the date.
total_games_in_progressintegerGames currently in progress on the date.
game_pkintegerUnique game identifier.
game_guidcharacterGlobally unique game identifier (GUID).
linkcharacterAPI link to the game feed.
game_typecharacterPostseason game type code (e.g. 'F', 'D', 'W').
seasoncharacterSeason the game belongs to.
game_datecharacterGame date-time in UTC (ISO 8601).
official_datecharacterOfficial game date (YYYY-MM-DD).
is_tielogicalWhether the game ended in a tie.
is_featured_gamelogicalWhether the game is a featured game.
game_numberintegerGame number within a doubleheader.
public_facinglogicalWhether the game is public-facing.
double_headercharacterDoubleheader indicator ('N', 'S', 'Y').
gameday_typecharacterGameday data feed type.
tiebreakercharacterWhether the game is a tiebreaker.
calendar_event_idcharacterCalendar event identifier.
season_displaycharacterDisplay string for the season.
day_nightcharacterDay or night game indicator.
descriptioncharacterSeries/round description (e.g. 'AL Wild Card Game').
scheduled_inningsintegerScheduled number of innings.
reverse_home_away_statuslogicalWhether home/away teams are reversed.
games_in_seriesintegerNumber of games in the series.
series_game_numberintegerGame number within the series.
series_descriptioncharacterDescription of the series.
record_sourcecharacterSource of the schedule record.
if_necessarycharacterWhether the game is played only if necessary.
if_necessary_descriptioncharacterDescription of the if-necessary status.
status_abstract_game_statecharacterAbstract game state (e.g. 'Final').
status_coded_game_statecharacterCoded game state.
status_detailed_statecharacterDetailed game state.
status_status_codecharacterStatus code for the game.
status_start_time_tbdlogicalWhether the start time is TBD.
status_abstract_game_codecharacterAbstract game state code.
teams_away_scoreintegerAway team score.
teams_away_is_winnerlogicalWhether the away team won.
teams_away_split_squadlogicalWhether the away team is a split squad.
teams_away_series_numberintegerAway team's series number.
teams_away_team_idintegerAway team MLBAM ID.
teams_away_team_namecharacterAway team name.
teams_away_team_linkcharacterAPI link to the away team.
teams_away_league_record_winsintegerAway team series-record wins.
teams_away_league_record_lossesintegerAway team series-record losses.
teams_away_league_record_pctcharacterAway team winning percentage.
teams_home_scoreintegerHome team score.
teams_home_is_winnerlogicalWhether the home team won.
teams_home_split_squadlogicalWhether the home team is a split squad.
teams_home_series_numberintegerHome team's series number.
teams_home_team_idintegerHome team MLBAM ID.
teams_home_team_namecharacterHome team name.
teams_home_team_linkcharacterAPI link to the home team.
teams_home_league_record_winsintegerHome team series-record wins.
teams_home_league_record_lossesintegerHome team series-record losses.
teams_home_league_record_pctcharacterHome team winning percentage.
venue_idintegerMLBAM venue ID.
venue_namecharacterVenue name.
venue_linkcharacterAPI link to the venue.
content_linkcharacterAPI link to the game content.
inning_break_lengthintegerLength of inning breaks in seconds.
reschedule_datecharacterReschedule date-time, if rescheduled.
reschedule_game_datecharacterReschedule game date, if rescheduled.
status_reasoncharacterReason for the game status (e.g. 'Rain').
rescheduled_fromcharacterOriginal date-time the game was rescheduled from.
rescheduled_from_datecharacterOriginal date the game was rescheduled from.
eventslistNested list of non-game events.

Examples

# \donttest{
  try(mlb_schedule_postseason(season = 2021))
#> ── MLB Schedule - Post-season data from MLB.com ───── baseballr 2.0.0 ──
#>  Data updated: 2026-06-12 14:09:50 UTC
#> # A tibble: 38 × 70
#>    date      total_items total_events total_games total_games_in_progr…¹
#>    <chr>           <int>        <int>       <int>                  <int>
#>  1 2021-10-…           1            0           1                      0
#>  2 2021-10-…           1            0           1                      0
#>  3 2021-10-…           2            0           2                      0
#>  4 2021-10-…           2            0           2                      0
#>  5 2021-10-…           4            0           4                      0
#>  6 2021-10-…           4            0           4                      0
#>  7 2021-10-…           4            0           4                      0
#>  8 2021-10-…           4            0           4                      0
#>  9 2021-10-…           2            0           2                      0
#> 10 2021-10-…           2            0           2                      0
#> # ℹ 28 more rows
#> # ℹ abbreviated name: ¹​total_games_in_progress
#> # ℹ 65 more variables: game_pk <int>, game_guid <chr>, link <chr>,
#> #   game_type <chr>, season <chr>, game_date <chr>,
#> #   official_date <chr>, is_tie <lgl>, is_featured_game <lgl>,
#> #   game_number <int>, public_facing <lgl>, double_header <chr>,
#> #   gameday_type <chr>, tiebreaker <chr>, calendar_event_id <chr>, …
# }