Skip to contents

Find game_pk values for professional baseball postseason series games (major and minor leagues)

Usage

mlb_schedule_postseason_series(
  season = 2021,
  game_type = NULL,
  series_number = NULL,
  sport_id = 1,
  team_id = NULL
)

Arguments

season

The season for which you want to find game_pk values for MLB games

game_type

game_type to return schedule information for all tied games in a particular game_type

series_number

The Series number to return schedule information for all tied games in a particular series number

sport_id

The sport_id to return schedule information for.

team_id

The team_id to return schedule information for.

game_type_idgame_type_description
SSpring Training
RRegular Season
FWild Card Game
DDivision Series
LLeague Championship Series
WWorld Series
CChampionship
NNineteenth Century Series
PPlayoffs
AAll-Star Game
IIntrasquad
EExhibition

Value

Returns a tibble that includes game_pk values and additional information for games scheduled or played

col_nametypesdescription
total_itemsintegerTotal games in the series.
total_gamesintegerTotal games in the series.
total_games_in_progressintegerGames currently in progress.
game_pkintegerUnique game identifier.
game_guidcharacterGlobally unique game identifier (GUID).
linkcharacterAPI link to the game feed.
game_typecharacterPostseason game type code (e.g. 'W', 'L', 'D').
seasoncharacterSeason the game belongs to.
game_datecharacterGame date-time in UTC (ISO 8601).
official_datecharacterOfficial game date (YYYY-MM-DD).
is_tielogicalWhether the game ended in a tie.
is_featured_gamelogicalWhether the game is a featured game.
game_numberintegerGame number within a doubleheader.
public_facinglogicalWhether the game is public-facing.
double_headercharacterDoubleheader indicator ('N', 'S', 'Y').
gameday_typecharacterGameday data feed type.
tiebreakercharacterWhether the game is a tiebreaker.
calendar_event_idcharacterCalendar event identifier.
season_displaycharacterDisplay string for the season.
day_nightcharacterDay or night game indicator.
descriptioncharacterSeries/game description (e.g. 'World Series Game 1').
scheduled_inningsintegerScheduled number of innings.
reverse_home_away_statuslogicalWhether home/away teams are reversed.
inning_break_lengthintegerLength of inning breaks in seconds.
games_in_seriesintegerNumber of games in the series.
series_game_numberintegerGame number within the series.
series_descriptioncharacterDescription of the series.
record_sourcecharacterSource of the schedule record.
if_necessarycharacterWhether the game is played only if necessary.
if_necessary_descriptioncharacterDescription of the if-necessary status.
status_abstract_game_statecharacterAbstract game state (e.g. 'Final').
status_coded_game_statecharacterCoded game state.
status_detailed_statecharacterDetailed game state.
status_status_codecharacterStatus code for the game.
status_start_time_tbdlogicalWhether the start time is TBD.
status_abstract_game_codecharacterAbstract game state code.
teams_away_scoreintegerAway team score.
teams_away_is_winnerlogicalWhether the away team won.
teams_away_split_squadlogicalWhether the away team is a split squad.
teams_away_series_numberintegerAway team's series number.
teams_away_team_idintegerAway team MLBAM ID.
teams_away_team_namecharacterAway team name.
teams_away_team_linkcharacterAPI link to the away team.
teams_away_league_record_winsintegerAway team series-record wins.
teams_away_league_record_lossesintegerAway team series-record losses.
teams_away_league_record_pctcharacterAway team winning percentage.
teams_home_scoreintegerHome team score.
teams_home_is_winnerlogicalWhether the home team won.
teams_home_split_squadlogicalWhether the home team is a split squad.
teams_home_series_numberintegerHome team's series number.
teams_home_team_idintegerHome team MLBAM ID.
teams_home_team_namecharacterHome team name.
teams_home_team_linkcharacterAPI link to the home team.
teams_home_league_record_winsintegerHome team series-record wins.
teams_home_league_record_lossesintegerHome team series-record losses.
teams_home_league_record_pctcharacterHome team winning percentage.
venue_idintegerMLBAM venue ID.
venue_namecharacterVenue name.
venue_linkcharacterAPI link to the venue.
content_linkcharacterAPI link to the game content.
reschedule_datecharacterReschedule date-time, if rescheduled.
reschedule_game_datecharacterReschedule game date, if rescheduled.
rescheduled_fromcharacterOriginal date-time the game was rescheduled from.
rescheduled_from_datecharacterOriginal date the game was rescheduled from.
status_reasoncharacterReason for the game status (e.g. 'Rain').
sort_orderintegerSort order within the series listing.
series_idcharacterSeries identifier (e.g. 'W_1').
series_sort_numberintegerSort number for the series.
series_is_defaultlogicalWhether the series is the default series.
series_game_typecharacterGame type code for the series.

Examples

# \donttest{
  try(mlb_schedule_postseason_series(season = 2021, sport_id = 1))
#> ── MLB Schedule - Post-season Series data from MLB.com ─────────────────
#>  Data updated: 2026-06-12 14:09:51 UTC
#> # A tibble: 38 × 72
#>    total_items total_games total_games_in_progress game_pk game_guid    
#>          <int>       <int>                   <int>   <int> <chr>        
#>  1           6           6                       0  660897 c4148dd0-dc0…
#>  2           6           6                       0  660908 8644ecec-18e…
#>  3           6           6                       0  660910 404871b2-3eb…
#>  4           6           6                       0  660902 d8d931dc-494…
#>  5           6           6                       0  660911 ad3ef28d-964…
#>  6           6           6                       0  660906 35a3ffd6-2d4…
#>  7           1           1                       0  660938 42ec699b-0d4…
#>  8           1           1                       0  660937 c4cc7a37-663…
#>  9           5           5                       0  660936 99c5d8e9-125…
#> 10           5           5                       0  660934 0e6aa0d8-ec6…
#> # ℹ 28 more rows
#> # ℹ 67 more variables: link <chr>, game_type <chr>, season <chr>,
#> #   game_date <chr>, official_date <chr>, is_tie <lgl>,
#> #   is_featured_game <lgl>, game_number <int>, public_facing <lgl>,
#> #   double_header <chr>, gameday_type <chr>, tiebreaker <chr>,
#> #   calendar_event_id <chr>, season_display <chr>, day_night <chr>,
#> #   description <chr>, scheduled_innings <int>, …
# }