Skip to contents

MLB Teams History

Usage

mlb_team_history(team_ids = NULL, start_season = NULL, end_season = NULL)

Arguments

team_ids

The team_id(s) to return historical data for.

start_season

The start_season to return historical data for from the given year to present.

end_season

The end_season to return historical data for from the the creation to the given year.

Value

Returns a tibble with the following columns

col_nametypesdescription
all_star_statuscharacterAll-star status flag.
team_idintegerTeam MLBAM ID.
team_full_namecharacterFull team name.
linkcharacterAPI link to the team.
seasonintegerSeason year for the historical record.
team_codecharacterInternal team code.
file_codecharacterFile code abbreviation.
team_abbreviationcharacterTeam abbreviation.
team_namecharacterShort team name.
location_namecharacterTeam location (city).
first_year_of_playcharacterFirst year the franchise played.
short_namecharacterShort display name.
franchise_namecharacterFranchise name.
club_namecharacterClub name.
activelogicalWhether the team is active.
venue_idintegerHome venue MLBAM ID for that season.
venue_namecharacterHome venue name for that season.
venue_linkcharacterAPI link to the venue.
spring_venue_idintegerSpring training venue MLBAM ID.
spring_venue_linkcharacterAPI link to the spring venue.
league_idintegerLeague MLBAM ID.
league_namecharacterLeague name.
league_linkcharacterAPI link to the league.
sport_idintegerSport MLBAM ID.
sport_linkcharacterAPI link to the sport.
sport_namecharacterSport name (e.g., Major League Baseball).

Examples

# \donttest{
  try(mlb_team_history(team_ids = 147))
#> ── MLB Team History data from MLB.com ─────────────── baseballr 2.0.0 ──
#>  Data updated: 2026-06-08 11:09:29 UTC
#> # A tibble: 5 × 26
#>   all_star_status team_id team_full_name       link     season team_code
#>   <chr>             <int> <chr>                <chr>     <int> <chr>    
#> 1 N                   147 New York Yankees     /api/v1…   2009 nya      
#> 2 N                   147 New York Yankees     /api/v1…   1974 nya      
#> 3 N                   147 New York Yankees     /api/v1…   1923 nya      
#> 4 N                   147 New York Yankees     /api/v1…   1913 nya      
#> 5 N                   147 New York Highlanders /api/v1…   1903 nya      
#> # ℹ 20 more variables: file_code <chr>, team_abbreviation <chr>,
#> #   team_name <chr>, location_name <chr>, first_year_of_play <chr>,
#> #   short_name <chr>, franchise_name <chr>, club_name <chr>,
#> #   active <lgl>, venue_id <int>, venue_name <chr>, venue_link <chr>,
#> #   spring_venue_id <int>, spring_venue_link <chr>, league_id <int>,
#> #   league_name <chr>, league_link <chr>, sport_id <int>,
#> #   sport_link <chr>, sport_name <chr>
# }