Skip to contents

MLB Teams Stats

Usage

mlb_teams_stats(
  stat_type = NULL,
  game_type = NULL,
  stat_group = NULL,
  season = NULL,
  sport_ids = NULL,
  sort_stat = NULL,
  order = NULL
)

Arguments

stat_type

Stat type to return statistics for.

game_type

Game type to return information for a particular statistic in a particular game type.

stat_group

Stat group to return information and ranking for a particular statistic in a particular group.

season

Year to return information and ranking for a particular statistic in a given year.

sport_ids

The sport_id(s) to return information and ranking information for.

sort_stat

Sort return based on stat.

order

Order return based on either desc or asc.

Value

Returns a tibble with the following columns

col_nametypesdescription
total_splitsintegerTotal number of splits in the response.
seasoncharacterSeason year for the statistic.
rankintegerRank of the team for the sorted statistic.
games_playedintegerGames played.
ground_outsintegerGround outs.
air_outsintegerAir outs (fly outs).
runsintegerRuns scored.
doublesintegerDoubles.
triplesintegerTriples.
home_runsintegerHome runs.
strike_outsintegerStrikeouts.
base_on_ballsintegerWalks (bases on balls).
intentional_walksintegerIntentional walks.
hitsintegerHits.
hit_by_pitchintegerTimes hit by pitch.
avgcharacterBatting average.
at_batsintegerAt bats.
obpcharacterOn-base percentage.
slgcharacterSlugging percentage.
opscharacterOn-base plus slugging.
caught_stealingintegerTimes caught stealing.
stolen_basesintegerStolen bases.
stolen_base_percentagecharacterStolen base success percentage.
caught_stealing_percentagecharacterCaught stealing percentage.
ground_into_double_playintegerGrounded into double plays.
number_of_pitchesintegerTotal pitches seen.
plate_appearancesintegerPlate appearances.
total_basesintegerTotal bases.
rbiintegerRuns batted in.
left_on_baseintegerRunners left on base.
sac_buntsintegerSacrifice bunts.
sac_fliesintegerSacrifice flies.
babipcharacterBatting average on balls in play.
ground_outs_to_airoutscharacterRatio of ground outs to air outs.
catchers_interferenceintegerTimes reached on catcher's interference.
at_bats_per_home_runcharacterAt bats per home run.
team_idintegerTeam MLBAM ID.
team_namecharacterTeam name.
team_linkcharacterAPI link to the team.
splits_tied_with_offsetlistTeams tied at the offset boundary.
splits_tied_with_limitlistTeams tied at the limit boundary.
type_display_namecharacterStat type display name.
group_display_namecharacterStat group display name.

Examples

# \donttest{
  try(mlb_teams_stats(stat_type = 'season', stat_group = 'hitting', season = 2021))
#> ── MLB Teams Stats data from MLB.com ──────────────── baseballr 2.0.0 ──
#>  Data updated: 2026-06-12 14:09:58 UTC
#> # A tibble: 50 × 43
#>    total_splits season  rank games_played ground_outs air_outs  runs
#>           <int> <chr>  <int>        <int>       <int>    <int> <int>
#>  1          371 2021       1            2           8        6    10
#>  2          371 2021       2            2          14       19    18
#>  3          371 2021       3            2          14        8     9
#>  4          371 2021       4            1           4       17     7
#>  5          371 2021       5            2          18       15    19
#>  6          371 2021       6            1           9        7    13
#>  7          371 2021       7           63         546      495   500
#>  8          371 2021       8            1           8        4     9
#>  9          371 2021       9            3          24       26    23
#> 10          371 2021      10           66         593      594   438
#> # ℹ 40 more rows
#> # ℹ 36 more variables: doubles <int>, triples <int>, home_runs <int>,
#> #   strike_outs <int>, base_on_balls <int>, intentional_walks <int>,
#> #   hits <int>, hit_by_pitch <int>, avg <chr>, at_bats <int>,
#> #   obp <chr>, slg <chr>, ops <chr>, caught_stealing <int>,
#> #   stolen_bases <int>, stolen_base_percentage <chr>,
#> #   caught_stealing_percentage <chr>, ground_into_double_play <int>, …
# }