Skip to contents

Retrieve lineups for a given NCAA game via its game_info_url

Usage

ncaa_lineups(game_info_url = NULL, ...)

Arguments

game_info_url

The unique game info url

...

Additional arguments passed to an underlying function like httr.

Value

Returns a tibble of each team's batting lineup (one row per batter, in batting order) parsed from the game's individual_stats box scores.

col_nametypesdescription
player_namecharacterPlayer name.
positioncharacterFielding position (the box score "P" column).
batting_orderintegerSpot in the batting order (box-score row order).
team_namecharacterTeam name (from the box-score totals row).
player_idintegerstats.ncaa.org player identifier.
player_urlcharacterFull stats.ncaa.org url for the player page.
slugcharacterRelative stats.ncaa.org url for the player page.

Details

Live usage (reads stats.ncaa.org, which is behind Akamai bot protection and needs the optional chromote + Google Chrome browser fallback, so it is shown here rather than as a runnable example):

ncaa_lineups(game_info_url = "https://stats.ncaa.org/contests/2167178/box_score")
ncaa_lineups(game_info_url = "https://stats.ncaa.org/game/index/4587474?org_id=528")