Skip to contents

This function allows the user to look up the team_id needed for the ncaa_team_player_stats() function.

Usage

ncaa_school_id_lu(team_name = NULL)

Arguments

team_name

A string that will be searched for in the names of the teams.

Value

Returns a tibble with school identification data: team_id, team_name, team_url, conference, conference_id, division, year, and season_id

col_nametypesdescription
team_idnumericTeam NCAA id.
team_namecharacterTeam name.
team_urlcharacterRelative stats.ncaa.org team url.
conference_idnumericConference identifier.
conferencecharacterConference name.
divisionnumericNCAA division (1, 2, 3).
yearnumericSeason (4-digit year).
season_idnumericstats.ncaa.org season identifier.

Details

Example usage (resolved from the bundled NCAA teams table):