Skip to contents

This function allows the user to obtain NCAA teams by year and division

Usage

ncaa_teams(year = most_recent_ncaa_baseball_season(), division = 1, ...)

Arguments

year

The season for which data should be returned, in the form of "YYYY". Years currently available: 2002 onward.

division

Division - 1, 2, 3

...

Additional arguments passed to an underlying function like httr.

Value

A data frame with the following variables

col_nametypesdescription
team_idcharacterFranchise team id (legacy /team/{id}/... urls).
team_namecharacterTeam display name.
team_urlcharacterRelative team url from stats.ncaa.org.
conference_idcharacterConference identifier.
conferencecharacterConference name.
divisionnumericNCAA division (1, 2, 3).
yearnumericSeason (4-digit year).
season_idcharacterSeason id (legacy urls); join key to season ids.
season_team_idcharacterSeason-team id (modern /teams/{id} urls).

Details

ncaa_teams(2023, 1)