Learn R Programming

baseballr (version 2.0.0)

playerid_lookup: Look up Baseball Player IDs by Player Name

Description

This function allows you to query the Chadwick Bureau's public register of baseball players and the various IDs associated with them in different systems of record.

Usage

playerid_lookup(last_name = NULL, first_name = NULL)

Value

A data frame of baseball players and the various IDs associated with them in different systems of record.

col_nametypesdescription
first_namecharacterPlayer first name.
last_namecharacterPlayer last name.
given_namecharacterPlayer full given (legal) name.
name_suffixcharacterName suffix (e.g. Jr., Sr., III).
nick_namecharacterPlayer nickname.
birth_yearintegerYear of birth.
mlb_played_firstintegerFirst MLB season as a player.
mlbam_idintegerMLB Advanced Media (MLBAM) player ID.
retrosheet_idcharacterRetrosheet player ID.
bbref_idcharacterBaseball-Reference player ID.
fangraphs_idintegerFanGraphs player ID.

Arguments

last_name

A text string used to return results for players with that string in their last name.

first_name

A text string used to return results for players with that string in their first name.

Examples

Run this code
# \donttest{
  try(playerid_lookup("Garcia", "Karim"))
# }

Run the code above in your browser using DataLab